@@ -215,7 +215,6 @@ thunar_permissions_chooser_init (ThunarPermissionsChooser *chooser)
   chooser->grid = gtk_grid_new ();
   gtk_grid_set_column_spacing (GTK_GRID (chooser->grid), 12);
   gtk_grid_set_row_spacing (GTK_GRID (chooser->grid), 6);
-  gtk_container_set_border_width (GTK_CONTAINER (chooser->grid), 10);
   gtk_box_pack_start (GTK_BOX (chooser), chooser->grid, TRUE, TRUE, 0);
   gtk_widget_show (chooser->grid);
 
@@ -940,7 +939,7 @@ thunar_permissions_chooser_file_changed (ThunarPermissionsChooser *chooser)
       if (G_LIKELY (user != NULL))
         {
           groups = g_list_copy (thunar_user_get_groups (user));
-          g_list_foreach (groups, (GFunc) g_object_ref, NULL);
+          g_list_foreach (groups, (GFunc) (void (*)(void)) g_object_ref, NULL);
         }
     }
 
@@ -1010,14 +1009,9 @@ thunar_permissions_chooser_file_changed (ThunarPermissionsChooser *chooser)
       g_object_unref (G_OBJECT (access_store));
     }
 
-  /* update the program setting based on the mode (only visible for regular files, allowed for execution) */
+  /* update the program setting based on the mode (only visible for regular files) */
   g_signal_handlers_block_by_func (G_OBJECT (chooser->program_button), thunar_permissions_chooser_program_toggled, chooser);
-  g_object_set (G_OBJECT (chooser->program_button), "visible", thunar_file_is_regular (file)
-      && (thunarx_file_info_has_mime_type (THUNARX_FILE_INFO (file), "application/x-executable")
-       || thunarx_file_info_has_mime_type (THUNARX_FILE_INFO (file), "application/x-shellscript")
-       || thunarx_file_info_has_mime_type (THUNARX_FILE_INFO (file), "application/x-desktop")
-       || thunarx_file_info_has_mime_type (THUNARX_FILE_INFO (file), "application/x-ms-dos-executable")
-       || thunarx_file_info_has_mime_type (THUNARX_FILE_INFO (file), "application/x-msi")), NULL);
+  g_object_set (G_OBJECT (chooser->program_button), "visible", thunar_file_is_regular (file), NULL);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chooser->program_button), (mode & 0111) != 0);
   g_signal_handlers_unblock_by_func (G_OBJECT (chooser->program_button), thunar_permissions_chooser_program_toggled, chooser);
 
