@@ -39,6 +39,7 @@
 #endif
 
 #include <thunar/thunar-enum-types.h>
+#include <thunar/thunar-gio-extensions.h>
 #include <thunar/thunar-gobject-extensions.h>
 #include <thunar/thunar-preferences.h>
 #include <thunar/thunar-private.h>
@@ -75,15 +76,18 @@ enum
   PROP_MISC_VOLUME_MANAGEMENT,
   PROP_MISC_CASE_SENSITIVE,
   PROP_MISC_DATE_STYLE,
+  PROP_MISC_DATE_CUSTOM_STYLE,
   PROP_EXEC_SHELL_SCRIPTS_BY_DEFAULT,
   PROP_MISC_FOLDERS_FIRST,
   PROP_MISC_FULL_PATH_IN_TITLE,
   PROP_MISC_HORIZONTAL_WHEEL_NAVIGATES,
   PROP_MISC_IMAGE_SIZE_IN_STATUSBAR,
   PROP_MISC_MIDDLE_CLICK_IN_TAB,
+  PROP_MISC_OPEN_NEW_WINDOW_AS_TAB,
   PROP_MISC_RECURSIVE_PERMISSIONS,
   PROP_MISC_REMEMBER_GEOMETRY,
   PROP_MISC_SHOW_ABOUT_TEMPLATES,
+  PROP_MISC_SHOW_DELETE_ACTION,
   PROP_MISC_SINGLE_CLICK,
   PROP_MISC_SINGLE_CLICK_TIMEOUT,
   PROP_MISC_SMALL_TOOLBAR_ICONS,
@@ -207,7 +211,7 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                          "LastCompactViewZoomLevel",
                          NULL,
                          THUNAR_TYPE_ZOOM_LEVEL,
-                         THUNAR_ZOOM_LEVEL_SMALLEST,
+                         THUNAR_ZOOM_LEVEL_25_PERCENT,
                          EXO_PARAM_READWRITE);
 
 
@@ -272,7 +276,7 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                          "LastDetailsViewZoomLevel",
                          NULL,
                          THUNAR_TYPE_ZOOM_LEVEL,
-                         THUNAR_ZOOM_LEVEL_SMALLER,
+                         THUNAR_ZOOM_LEVEL_38_PERCENT,
                          EXO_PARAM_READWRITE);
 
   /**
@@ -285,7 +289,7 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                          "LastIconViewZoomLevel",
                          NULL,
                          THUNAR_TYPE_ZOOM_LEVEL,
-                         THUNAR_ZOOM_LEVEL_NORMAL,
+                         THUNAR_ZOOM_LEVEL_100_PERCENT,
                          EXO_PARAM_READWRITE);
 
   /**
@@ -492,6 +496,18 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                          THUNAR_DATE_STYLE_SIMPLE,
                          EXO_PARAM_READWRITE);
 
+  /**
+   * ThunarPreferences:misc-date-custom-style:
+   *
+   * If 'custom' is selected as date format, this date-style will be used
+   **/
+  preferences_props[PROP_MISC_DATE_CUSTOM_STYLE] =
+      g_param_spec_string ("misc-date-custom-style",
+                           "MiscDateCustomStyle",
+                           NULL,
+                           "%Y-%m-%d %H:%M:%S",
+                           EXO_PARAM_READWRITE);
+
   /**
    * ThunarPreferences:misc-execute-shell-scripts-by-default:
    *
@@ -572,6 +588,19 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                             FALSE,
                             EXO_PARAM_READWRITE);
 
+  /**
+   * ThunarPreferences:misc-open-new-window-as_tab:
+   *
+   * %TRUE to open a new tab in an existing thunar instance. instead of a new window
+   * if a thunar windows already is present
+   **/
+  preferences_props[PROP_MISC_OPEN_NEW_WINDOW_AS_TAB] =
+      g_param_spec_boolean ("misc-open-new-window-as-tab",
+                            "MiscOpenNewWindowAsTab",
+                            NULL,
+                            FALSE,
+                            EXO_PARAM_READWRITE);
+
   /**
    * ThunarPreferences:misc-recursive-permissions:
    *
@@ -615,6 +644,19 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                             TRUE,
                             EXO_PARAM_READWRITE);
 
+ /**
+   * ThunarPreferences:misc-show-delete-action:
+   *
+   * Whether to display a "delete" action to permanently delete files and folders
+   * If trash is not supported, "delete" is displayed by default.
+   **/
+  preferences_props[PROP_MISC_SHOW_DELETE_ACTION] =
+      g_param_spec_boolean ("misc-show-delete-action",
+                            "MiscShowDeleteAction",
+                            NULL,
+                            !thunar_g_vfs_is_uri_scheme_supported ("trash"),
+                            EXO_PARAM_READWRITE);
+
   /**
    * ThunarPreferences:misc-single-click:
    *
@@ -702,7 +744,7 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
       g_param_spec_boolean ("misc-file-size-binary",
                             "MiscFileSizeBinary",
                             NULL,
-                            FALSE,
+                            TRUE,
                             EXO_PARAM_READWRITE);
 
   /**
@@ -729,7 +771,7 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                          "ShortcutsIconSize",
                          NULL,
                          THUNAR_TYPE_ICON_SIZE,
-                         THUNAR_ICON_SIZE_SMALLER,
+                         THUNAR_ICON_SIZE_24,
                          EXO_PARAM_READWRITE);
 
   /**
@@ -756,7 +798,7 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                          "TreeIconSize",
                          NULL,
                          THUNAR_TYPE_ICON_SIZE,
-                         THUNAR_ICON_SIZE_SMALLEST,
+                         THUNAR_ICON_SIZE_16,
                          EXO_PARAM_READWRITE);
 
   /* install all properties */
