@@ -295,7 +295,7 @@ thunar_tree_model_init (ThunarTreeModel *model)
 
   /* initialize the model data */
   model->sort_case_sensitive = TRUE;
-  model->visible_func = (ThunarTreeModelVisibleFunc) exo_noop_true;
+  model->visible_func = (ThunarTreeModelVisibleFunc) (void (*)(void)) exo_noop_true;
   model->visible_data = NULL;
   model->cleanup_idle_id = 0;
 
